Index: pbx/pbx_config.c
===================================================================
--- pbx/pbx_config.c	(revision 197925)
+++ pbx/pbx_config.c	(working copy)
@@ -55,6 +55,8 @@
 
 static struct ast_context *local_contexts = NULL;
 
+static int reload(void);
+
 /*
  * Help for commands provided by this module ...
  */
@@ -2143,6 +2145,12 @@
 	handle_save_dialplan, "Save dialplan",
 	save_dialplan_help, NULL, &cli_save_dialplan_deprecated };
 
+static void manager_loaded(void)
+{
+	/* Now that the manager has been loaded, we reload */
+	reload();
+}
+
 /*!
  * Standard module functions ...
  */
@@ -2152,6 +2160,7 @@
 		ast_cli_unregister(&cli_dialplan_save);
 	ast_cli_unregister_multiple(cli_pbx_config, sizeof(cli_pbx_config) / sizeof(struct ast_cli_entry));
 	ast_context_destroy(NULL, registrar);
+	ast_unregister_manager_listener(manager_loaded);
 	return 0;
 }
 
@@ -2468,6 +2477,8 @@
 		ast_cli_register(&cli_dialplan_save);
 	ast_cli_register_multiple(cli_pbx_config, sizeof(cli_pbx_config) / sizeof(struct ast_cli_entry));
 
+	ast_register_manager_listener(manager_loaded);
+
 	return 0;
 }
 
Index: include/asterisk.h
===================================================================
--- include/asterisk.h	(revision 197925)
+++ include/asterisk.h	(working copy)
@@ -139,6 +139,9 @@
  */
 void ast_unregister_atexit(void (*func)(void));
 
+void ast_register_manager_listener(void (*callback)(void));
+void ast_unregister_manager_listener(void (*callback)(void));
+
 #if !defined(LOW_MEMORY)
 /*!
  * \brief Register the version of a source code file with the core.
Index: main/asterisk.c
===================================================================
--- main/asterisk.c	(revision 197925)
+++ main/asterisk.c	(working copy)
@@ -253,6 +253,54 @@
 	 unsigned int need_quit:1;
 } sig_flags;
 
+struct manager_load_listener {
+	void (*callback)(void);
+	AST_RWLIST_ENTRY(manager_load_listener) list;
+};
+
+static AST_RWLIST_HEAD_STATIC(manager_listeners, manager_load_listener);
+
+void ast_register_manager_listener(void (*callback)(void))
+{
+	struct manager_load_listener *listener;
+
+	if (!callback)
+		return;
+
+	listener = ast_calloc(1, sizeof(*listener));
+	listener->callback = callback;
+
+	AST_RWLIST_WRLOCK(&manager_listeners);
+	AST_RWLIST_INSERT_TAIL(&manager_listeners, listener, list);
+	AST_RWLIST_UNLOCK(&manager_listeners);
+
+	return;
+}
+
+void ast_unregister_manager_listener(void (*callback)(void))
+{
+	struct manager_load_listener *listener;
+
+	if (!callback)
+		return;
+
+	AST_RWLIST_WRLOCK(&manager_listeners);
+	AST_RWLIST_TRAVERSE_SAFE_BEGIN(&manager_listeners, listener, list) {
+		if (listener->callback == callback) {
+			AST_RWLIST_REMOVE_CURRENT(&manager_listeners, list);
+			break;
+		}
+	}
+	AST_RWLIST_TRAVERSE_SAFE_END;
+	AST_RWLIST_UNLOCK(&manager_listeners);
+
+	if (listener) {
+		ast_free(listener);
+	}
+
+	return;
+}
+
 #if !defined(LOW_MEMORY)
 struct file_version {
 	AST_LIST_ENTRY(file_version) list;
@@ -3169,6 +3217,17 @@
 		exit(1);
 	}
 
+	{
+		struct manager_load_listener *listener;
+
+		/* Now that manager is loaded, notify any listeners */
+		AST_RWLIST_RDLOCK(&manager_listeners);
+		AST_RWLIST_TRAVERSE(&manager_listeners, listener, list) {
+			listener->callback();
+		}
+		AST_RWLIST_UNLOCK(&manager_listeners);
+	}
+
 	dnsmgr_start_refresh();
 
 	/* We might have the option of showing a console, but for now just
